==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/NextWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { NextWeekExpressionDescription } from "./NextWeekExpressionDescription";
/**
 * @hidden
 */
export let NextWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextWeekExpressionDescriptionMetadata.a == null) {
                NextWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextWeekExpressionDescriptionMetadata.c(NextWeekExpressionDescriptionMetadata.a);
            }
            if (a.j(NextWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(NextWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            OffsettableWeekExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextWeekExpressionDescriptionMetadata.b(a);
            a.aa("NextWeekExpression", () => new NextWeekExpressionDescription());
            a.z("NextWeekExpression", NextWeekExpressionDescriptionMetadata.a);
        }
    }
    NextWeekExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(NextWeekExpressionDescriptionMetadata, 'NextWeekExpressionDescriptionMetadata');
    NextWeekExpressionDescriptionMetadata.a = null;
    return NextWeekExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/NextWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { NextWeekExpressionDescription } from "./NextWeekExpressionDescription";
/**
 * @hidden
 */
export let NextWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextWeekExpressionDescriptionMetadata.a == null) {
                NextWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextWeekExpressionDescriptionMetadata.c(NextWeekExpressionDescriptionMetadata.a);
            }
            if (a.k(NextWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(NextWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            OffsettableWeekExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextWeekExpressionDescriptionMetadata.b(a);
            a.ac("NextWeekExpression", () => new NextWeekExpressionDescription());
            a.ab("NextWeekExpression", NextWeekExpressionDescriptionMetadata.a);
        }
    }
    NextWeekExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(NextWeekExpressionDescriptionMetadata, 'NextWeekExpressionDescriptionMetadata');
    NextWeekExpressionDescriptionMetadata.a = null;
    return NextWeekExpressionDescriptionMetadata;
})();
